"use strict";
// based on https://github.com/vercel/next-site/blob/e2cb07a057bf75bded2571a1b639b0017572f4b8/lib/docs/markdown-to-html.js
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.markdownToHtml = void 0;
const unified_1 = __importDefault(require("unified"));
const remark_parse_1 = __importDefault(require("remark-parse"));
const remark_rehype_1 = __importDefault(require("remark-rehype"));
const rehype_raw_1 = __importDefault(require("rehype-raw"));
const rehype_prism_1 = __importDefault(require("@mapbox/rehype-prism"));
const rehype_stringify_1 = __importDefault(require("rehype-stringify"));
// https://github.com/syntax-tree/hast-util-sanitize/blob/master/lib/github.json
const github_json_1 = __importDefault(require("hast-util-sanitize/lib/github.json"));
const rehypeDocs_1 = __importDefault(require("./rehypeDocs"));
const rehypeMarkdownToHtml_1 = __importDefault(require("./rehypeMarkdownToHtml"));
// Allow className for all elements
github_json_1.default.attributes['*'].push('className');
const handlers = {
    // Add a className to inlineCode so we can differentiate between it and code fragments
    inlineCode(h, node) {
        return {
            ...node,
            type: 'element',
            tagName: 'code',
            properties: { className: 'inline' },
            children: [
                {
                    type: 'text',
                    value: node.value,
                },
            ],
        };
    },
};
async function markdownToHtml(filePath, tag, md) {
    try {
        // Init the processor with our custom plugin
        let processor = undefined;
        processor = (0, unified_1.default)()
            .use(remark_parse_1.default)
            .use(rehypeMarkdownToHtml_1.default, { filePath, tag, processor: () => processor })
            .use(remark_rehype_1.default, { handlers, allowDangerousHTML: true })
            // Add custom HTML found in the markdown file to the AST
            .use(rehype_raw_1.default)
            // Sanitize the HTML
            // .use(sanitize, githubSchema)
            // Add syntax highlighting to the sanitized HTML
            .use(rehype_prism_1.default)
            .use(rehype_stringify_1.default)
            .freeze()()
            .use(rehypeDocs_1.default, { filePath, tag, processor });
        const file = await processor.process(md);
        // Replace non-breaking spaces (char code 160) with normal spaces to avoid style issues
        return file.contents.replace(/\xA0/g, ' ');
    }
    catch (error) {
        console.error(`Markdown to HTML error: ${error}`);
        throw error;
    }
}
exports.markdownToHtml = markdownToHtml;
//# sourceMappingURL=markdownToHtml.js.map